==> excel2meta-interface-0.1.15.tar.gz: excel2meta-interface-0.1.15/excel2meta_interface/utils/messages.py <==
message = {
    "ok": {
        "code": "OK"
        , "message": "No errors encountered"
        , "level": "INFO"
        , "info": "none"
    },
    "not_implemented": {
        "code": "EMI-GEN-000"
        , "message": "Function not yet implemented. Please contact the development team and mention code 'EMI-GEN-000'."
        , "level": "ERROR"
        , "info": "none"
    },
    "not_found": {
        "code": "EMI-GEN-001"
        , "message": "Could not find what we were looking for"
        , "level": "ERROR"
        , "info": "none"
    },
    "os_error": {
        "code": "EMI-GEN-002"
        , "message": "An OS error occurred"
        , "level": "ERROR"
        , "info": "none"
    },
    "ignore": {
        "code": "EMI-GEN-003"
        , "message": "Entry has been ignored"
        , "level": "DEBUG"
        , "info": "none"
    },
    "undetermined": {
        "code": "EMI-GEN-004"
        ,
        "message": "Undetermined result. This should not happen. Please contact the development team and mention code 'EMI-GEN-004'."
        , "level": "ERROR"
        , "info": "none"
    },
    "main_config_not_found": {
        "code": "EMI-GEN-005"
        , "message": "Main configuration file not found."
        , "level": "FATAL"
        , "info": "none"
    },
    "internal_error": {
        "code": "EMI-GEN-006"
        , "message": "Internal error. Please contact the development team."
        , "level": "FATAL"
        , "info": "none"
    },
    "excel_not_found": {
        "code": "EMI-GEN-007"
        , "message": "Excel file could not be found."
        , "level": "ERROR"
        , "info": "none"
    },
    "write_error": {
        "code": "EMI-GEN-008"
        , "message": "IO error creating or writing to file."
        , "level": "ERROR"
        , "info": "none"
    },
    "jinja_template_name_not_provided": {
        "code": "EMI-JIN-001"
        , "message": "Internal error: Jinja template name not provided"
        , "level": "ERROR"
        , "info": "none"
    },
    "jinja_template_not_found": {
        "code": "EMI-JIN-002"
        , "message": "Jinja template not found."
        , "level": "ERROR"
        , "info": "none"
    },
    "schema_file_not_found": {
        "code": "EMI-SCH-001"
        , "message": "Schema file to check against was not found"
        , "level": "ERROR"
        , "info": "none"
    },
    "jsonschema_validation_error": {
        "code": "EMI-SCH-002"
        , "message": "JSON does not comply to the corresponding JSON schema"
        , "level": "ERROR"
        , "info": "none"
    }
    ,
    "json_schema_error": {
        "code": "EMI-SCH-003"
        , "message": "JSON schema error"
        , "level": "ERROR"
        , "info": "none"
    }
    ,
    "json_parse_error": {
        "code": "EMI-SCH-004"
        , "message": "JSON parse error"
        , "level": "ERROR"
        , "info": "none"
    }
    ,
    "entity_uuid_not_found": {
        "code": "EMI-PRC-001"
        , "message": "Could not find entity UUID"
        , "level": "ERROR"
        , "info": "none"
    }
}

==> excel2meta-interface-0.1.16.tar.gz: excel2meta-interface-0.1.16/excel2meta_interface/utils/messages.py <==
message = {
    "ok": {
        "code": "OK"
        , "message": "No errors encountered"
        , "level": "INFO"
        , "info": "none"
    },
    "not_implemented": {
        "code": "EMI-GEN-000"
        , "message": "Function not yet implemented. Please contact the development team and mention code 'EMI-GEN-000'."
        , "level": "ERROR"
        , "info": "none"
    },
    "not_found": {
        "code": "EMI-GEN-001"
        , "message": "Could not find what we were looking for"
        , "level": "ERROR"
        , "info": "none"
    },
    "os_error": {
        "code": "EMI-GEN-002"
        , "message": "An OS error occurred"
        , "level": "ERROR"
        , "info": "none"
    },
    "ignore": {
        "code": "EMI-GEN-003"
        , "message": "Entry has been ignored"
        , "level": "DEBUG"
        , "info": "none"
    },
    "undetermined": {
        "code": "EMI-GEN-004"
        ,
        "message": "Undetermined result. This should not happen. Please contact the development team and mention code 'EMI-GEN-004'."
        , "level": "ERROR"
        , "info": "none"
    },
    "main_config_not_found": {
        "code": "EMI-GEN-005"
        , "message": "Main configuration file not found."
        , "level": "FATAL"
        , "info": "none"
    },
    "internal_error": {
        "code": "EMI-GEN-006"
        , "message": "Internal error. Please contact the development team."
        , "level": "FATAL"
        , "info": "none"
    },
    "excel_not_found": {
        "code": "EMI-GEN-007"
        , "message": "Excel file could not be found."
        , "level": "ERROR"
        , "info": "none"
    },
    "write_error": {
        "code": "EMI-GEN-008"
        , "message": "IO error creating or writing to file."
        , "level": "ERROR"
        , "info": "none"
    },
    "jinja_template_name_not_provided": {
        "code": "EMI-JIN-001"
        , "message": "Internal error: Jinja template name not provided"
        , "level": "ERROR"
        , "info": "none"
    },
    "jinja_template_not_found": {
        "code": "EMI-JIN-002"
        , "message": "Jinja template not found."
        , "level": "ERROR"
        , "info": "none"
    },
    "schema_file_not_found": {
        "code": "EMI-SCH-001"
        , "message": "Schema file to check against was not found"
        , "level": "ERROR"
        , "info": "none"
    }, "jsonschema_validation_error": {
        "code": "EMI-SCH-002"
        , "message": "JSON does not comply to the corresponding JSON schema"
        , "level": "ERROR"
        , "info": "none"
    }, "json_schema_error": {
        "code": "EMI-SCH-003"
        , "message": "JSON schema error"
        , "level": "ERROR"
        , "info": "none"
    }, "json_parse_error": {
        "code": "EMI-SCH-004"
        , "message": "JSON parse error"
        , "level": "ERROR"
        , "info": "none"
    }, "entity_uuid_not_found": {
        "code": "EMI-SRCH-001"
        , "message": "Could not find entity UUID"
        , "level": "ERROR"
        , "info": "none"
    }, "source_attribute_not_in_source_entities": {
        "code": "EMI-SRCH-002"
        , "message": "Source attribute in not part of any source entity"
        , "level": "ERROR"
        , "info": "none"
    }, "target_attribute_not_in_target_entities": {
        "code": "EMI-SRCH-002"
        , "message": "Target attribute in not part of any target entity"
        , "level": "ERROR"
        , "info": "none"
    }
}
